
<div align="center">

# Snakifyer

### A simple to bot to automate problem submissions on [snakify.org](https://snakify.org/)

![image](https://ik.imagekit.io/gyzvlawdz/Projects/snakify/Add_a_heading_8qZu46hrQ.png)

</div>

## Installation
### Using git
```bash
git clone https://github.com/akashrchandran/snakifyer
```
### Change directory
```bash
cd snakifyer
```
### Install requirements
```bash
pip install -r requirements.txt
```
## Running

### Windows
```batch
py main.py
```
### Linux Or Termux
```bash
python3 main.py
```
